@@ -15,15 +15,9 @@ from kubernetes import client
 from kubernetes import config
 from kubernetes import utils
 from kubernetes import watch
-from vdk.internal.control.configuration.defaults_config import (
-    reset_default_authentication_disable,
-)
 from vdk.internal.control.configuration.defaults_config import (
     reset_default_rest_api_url,
 )
-from vdk.internal.control.configuration.defaults_config import (
-    write_default_authentication_disable,
-)
 from vdk.internal.control.configuration.defaults_config import (
     write_default_rest_api_url,
 )
@@ -78,7 +72,8 @@ class Installer:
         self.__install_ingress_prerequisites()
         self.__install_helm_chart()
         self.__finalize_configuration()
-        log.info(f"Versatile Data Kit Control Service installed successfully")
+        log.info("Versatile Data Kit Control Service installed successfully")
+        log.info("Access the REST API at http://localhost:8092/swagger-ui.html\n")
         log.info(
             "\n"
             "You can now use the other vdk commands to create, run, and deploy jobs. "
@@ -107,6 +102,7 @@ class Installer:
             and self.__docker_container_exists(self.docker_registry_container_name)
         ):
             log.info("The Versatile Data Kit Control Service is installed")
+            log.info("Access the REST API at http://localhost:8092/swagger-ui.html\n")
         else:
             log.info("No installation found")
 
@@ -758,7 +754,6 @@ class Installer:
         log.info("Finalizing installation...")
         try:
             write_default_rest_api_url("http://localhost:8092")
-            write_default_authentication_disable("true")
         except Exception as ex:
             log.error(f"Failed to finalize installation. {str(ex)}")
             exit(1)
@@ -769,7 +764,6 @@ class Installer:
         log.info("Cleaning up...")
         try:
             reset_default_rest_api_url()
-            reset_default_authentication_disable()
         except Exception as ex:
             log.error(f"Failed to clean up. {str(ex)}")
             exit(1)
